@@ -4,7 +4,7 @@ mod builder;
 
 pub(crate) use self::builder::Builder;
 
-use noodles_bgzf::index::Chunk;
+use noodles_csi::index::reference_sequence::bin::Chunk;
 
 use super::DEPTH;
 
