@@ -25,12 +25,18 @@
 //! # Ok::<(), io::Error>(())
 //! ```
 
+#[cfg(feature = "async")]
+pub mod r#async;
+
 pub mod index;
 mod reader;
 mod writer;
 
 pub use self::{index::Index, reader::Reader, writer::Writer};
 
+#[cfg(feature = "async")]
+pub use self::r#async::{Reader as AsyncReader, Writer as AsyncWriter};
+
 use std::{fs::File, io, path::Path};
 
 static MAGIC_NUMBER: &[u8] = b"TBI\x01";
@@ -55,3 +61,26 @@ where
     let mut reader = File::open(src).map(Reader::new)?;
     reader.read_index()
 }
+
+/// Writes a tabix index to a file.
+///
+/// This is a convenience function and is equivalent to creating a file at the given path and
+/// writing the index.
+///
+/// # Examples
+///
+/// ```no_run
+/// # use std::io;
+/// use noodles_tabix as tabix;
+/// let index = tabix::Index::default();
+/// tabix::write("sample.vcf.gz.tbi", &index)?;
+/// # Ok::<(), io::Error>(())
+/// ```
+pub fn write<P>(dst: P, index: &Index) -> io::Result<()>
+where
+    P: AsRef<Path>,
+{
+    let mut writer = File::create(dst).map(Writer::new)?;
+    writer.write_index(index)?;
+    Ok(())
+}
